@@ -3,7 +3,7 @@ import time
 from concurrent.futures import ThreadPoolExecutor
 from queue import Queue, Empty
 from threading import Lock, Condition, RLock
-from typing import List, Callable, Optional, Any
+from typing import Dict, List, Callable, Optional, Any
 
 import requests
 from requests import Session
@@ -52,7 +52,7 @@ class Task:
 class ProxyManager:
     def __init__(self,
                  test_url: str,
-                 proxy_info_dict: dict[str, List[str]],
+                 proxy_info_dict: Dict[str, List[str]],
                  num_executors=32,
                  executor_queue_size=1000,
                  verbose=False):
@@ -71,7 +71,7 @@ class ProxyManager:
         self._success = 0
         self._trials = 0
 
-    def _init_pool(self, info_dict: dict[str, List[str]]) -> ProxyPool:
+    def _init_pool(self, info_dict: Dict[str, List[str]]) -> ProxyPool:
         info_list = []
         for protocol, addresses in info_dict.items():
             for address in addresses:
@@ -101,8 +101,10 @@ class ProxyManager:
 
     def proxy_session(self,
                       fn: Callable[[Session, tuple], Optional[Any]],
-                      callback_async: Callable[[Optional[Any]], None] = lambda x: None,
-                      exception_handle: Callable[[ProxyInfo, Exception], None] = lambda info, ex: print(info, ex),
+                      callback_async: Callable[[
+                          Optional[Any]], None] = lambda x: None,
+                      exception_handle: Callable[[
+                          ProxyInfo, Exception], None] = lambda info, ex: print(info, ex),
                       args: tuple = (),
                       wait=False):
         """
